import Scraper


class Player:
    def __init__(self, player_id):
        self.search_type = "player"
        self.query = {"template": "results"}
        self.player_id = player_id
        self.cric_data = []

    def career_summary(self, query_params):
        self.query.update(query_params)
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def inn_list(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "innings"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def match_list(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "match"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def cumulative_avg(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "cumulative"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def reverse_cumulative(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "reverse_cumulative"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def series_avg(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "series"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def ground_avg(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "ground"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def match_results(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "results"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def match_awards(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "awards_match"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def series_awards(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "awards_series"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    # BATTING
    def partnership_summary(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "fow_summary"
        if self.query["type"] == "batting":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Partneship summary is only available for batting data")

    def dismissal_summary(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "dismissal_summary"
        if self.query["type"] == "batting":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Dismissal summary is only available for batting data")

    def bowler_summary(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "bowler_summary"
        if self.query["type"] == "batting":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Bowler summary is only available for batting data")

    def fielder_summary(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "fielder_summary"
        if self.query["type"] == "batting":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Fielder summary is only available for batting data")

    def dismissal_list(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "dismissal_list"
        if self.query["type"] == "batting":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Dismissal list is only available for batting data")

    # BOWLING
    def dism_summary(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "dismissal_summary"
        if self.query["type"] == "bowling":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Dismissal summary is only available for bowling data")

    def batsman_summary(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "batsman_summary"
        if self.query["type"] == "bowling":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Batsman summary is only available for bowling data")

    def fielder_summary(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "fielder_summary"
        if self.query["type"] == "bowling":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Fielder summary is only available for bowling data")

    def wickets_list(self, query_params):
        self.query.update(query_params)
        self.query["view"] = "dismissal_list"
        if self.query["type"] == "bowling":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Wickets list is only available for bowling data")



from player import Player
from team import Team
import json

import requests
from bs4 import BeautifulSoup
import pandas as pd

from helpers import data_extract

# All possible parameters
# query_params = {
#     'template': 'results',
#     'spanmax1': '07-Dec-2021', # The maximum date
#     'spanmin1': '05-Jan-1980', # The minimum date
#     'spanval1': 'span',
#     'team': '106', # The team chosen to filter by
#     'opposition': '2', # The opposition team
#     'result': '1', # The type of result which could be win / loss / n/r / abandoned (for the team chosen),
#     'ground': '1177', # The ground played on
#     'home_or_away': '1', # Whether the chosen team played home or away
#     'host': '19' # The host team / country
# }

query_params = {
    'class': '1',
    'type': 'batting'
}

# matchtot = team.get_by_season(query_params, limit=10)
# print(matchtot)
# player_id = 49764
# player = Player(player_id)
# cric_data = player.career_summary(query_params)
# print('Player')
# print(cric_data.head())

player = Player(49764)
cric_data = player.dismissal_summary(query_params)
print(len(cric_data))
# f = open('teams.json')

# data = json.load(f)
# data = {y: x for x, y in data.items()}

# with open("teams.json", "w") as outfile:
#     json.dump(data, outfile)


import requests
from bs4 import BeautifulSoup

url = 'https://stats.espncricinfo.com/ci/engine/stats/index.html?class=1;type=team'
# Get all stadiums and ids
def get_grounds():
    page = requests.get(url)
    soup = BeautifulSoup(page.content, 'html.parser')
    ground_list = {}

    grounds = soup.find('select', {'name': 'ground'})
    for ground in grounds:
        if(ground != '\n'):
            ground_list[ground.text] = ground['value']

    # Save to Json
    # with open('grounds.json', 'w') as outfile:
    #     json.dump(ground_list, outfile)

    return ground_list

# Get all the teams and ids
def get_teams():
    page = requests.get(url)
    soup = BeautifulSoup(page.content, 'html.parser')
    team_list = {}

    teams = soup.find('select', {'name': 'team'})
    for team in teams:
        if(team != '\n'):
            team_list[team.text] = team['value']

    # Save to Json
    # with open('grounds.json', 'w') as outfile:
    #     json.dump(ground_list, outfile)

    return team_list



from scraper import Scraper

# Classes
# Test = 1, ODI = 2, T20 = 3, All = 11
class Team:
    def __init__(self):
        self.query = {'type': 'team', 'template': 'results'}
        self.search_type = 'team'

    # OVERALL FIGURES
    def get_overall(self, query_params, limit=100):
        self.query.update(query_params)
        scraper = Scraper(self.query)
        cric_data = scraper.getTeamData(limit)

        return cric_data

    # INNINGS BY INNINGS
    def get_inns(self, query_params, limit=100):
        self.query.update(query_params)
        self.query['view'] = 'innings'
        cric_data = scraper.getTeamData(query, limit)

        return cric_data

    # MATCH TOTALS
    def get_matchtot(self, query_params, limit=100):
        self.query.update(query_params)
        self.query['view'] = 'match'
        cric_data = scraper.getTeamData(query, limit)

        return cric_data

    # MATCH RESULTS
    def get_matchres(self, query_params, limit=100):
        self.query.update(query_params)
        self.query['view'] = 'results'
        cric_data = scraper.getTeamData(query, limit)

        return cric_data

    # SERIES AVERAGE
    def get_series_avg(self, query_params,limit=100):
        self.query.update(query_params)
        self.query['view'] = 'series'
        cric_data = scraper.getTeamData(query, limit)

        return cric_data

    # GROUND AVERAGE
    def get_ground_avg(self, query_params,limit=100):
        self.query.update(query_params)
        self.query['view'] = 'ground'
        cric_data = scraper.getTeamData(query, limit)

        return cric_data

    # RESULTS BY HOST COUNTRY
    def get_by_host(self, query_params, limit=100):
        self.query.update(query_params)
        self.query['view'] = 'host'
        cric_data = scraper.getTeamData(query, limit)

        return cric_data

    # RESULTS BY OPPOSITION
    def get_by_opp(self, query_params, limit=100):
        self.query.update(query_params)
        self.query['view'] = 'opposition'
        cric_data = scraper.getTeamData(query, limit)

        return cric_data

    # BY YEAR
    def get_by_year(self, query_params, limit=100):
        self.query.update(query_params)
        self.query['view'] = 'year'
        cric_data = scraper.getTeamData(query, limit)

        return cric_data

    # BY SEASON
    def get_by_season(self, query_params, limit=100):
        self.query.update(query_params)
        self.query['view'] = 'season'
        cric_data = scraper.getTeamData(query, limit)

        return cric_data

    # OVERALL EXTRAS
    def get_overall_extras(self, query_params, limit=100):
        self.query.update(query_params)
        self.query['view'] = 'extras'
        cric_data = scraper.getTeamData(query, limit)

        return cric_data

    # EXTRAS BY INNINGS
    def get_extras_inn(self, query_params, limit=100):
        self.query.update(query_params)
        self.query['view'] = 'extras_innings'
        cric_data = scraper.getTeamData(query, limit)

        return cric_data



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cricguru', 'cricguru.helpers']

package_data = \
{'': ['*']}

install_requires = \
['bs4>=0.0.1,<0.0.2', 'pandas>=1.5.2,<2.0.0']

setup_kwargs = {
    'name': 'cricguru',
    'version': '0.3.0',
    'description': '',
    'long_description': '# cricguru\n\nA work in progress module for the CricInfo StatsGuru data.\n',
    'author': 'Pavithran',
    'author_email': 'pavithranthilakanathan@gmai.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/puppetmaster12/cricguru',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
